@@ -107,6 +107,14 @@ void	config(int argc, char **argv)
                         {
                                 if (atoi(pnt)) CallCheck = TRUE;
                         }
+                        else if (!memcmp (buff, "DPRS_MODE", 9))
+                        {
+                                if (atoi(pnt)) DprsSW = TRUE;
+                        }
+                        else if (!memcmp (buff, "DPRS_STRIP", 10))
+                        {
+                                if (atoi(pnt)) DprsStrip = TRUE;
+                        }
 		}
 	}
 	fclose (config_file);
