@@ -23,6 +23,7 @@
 	2014.02.13 V00.17 Changed Busy logic
 	2014.02.14 V00.18 Changed Hole Punching packet format
 	2014.02.16 V00.19 Bug fixed for CallCheck
+	2014.02.17 V00.20 Added DPRS Switch & DPRS STRIP
 */
 
 #include	"dsgwd_pi.h"
@@ -344,6 +345,9 @@ int main(int argc, const char **argv)
 	NodeVendorID =  VendorID;
 	NodeProductID = ProductID;
 	CallCheck = FALSE;
+	DprsSW = FALSE;
+	DprsStrip = FALSE;
+	DprsStripSW = FALSE;
 
 	config (argc, (char **)argv);
 
