@@ -130,12 +130,15 @@ void	from_rig(void)
 							if ((SlowData[0] & 0xf0) == 0x30) DprsData (SlowData);
 						}
 					}
-					if (((BitsCheck((char *)voice, NullVoice0, 9) < MaxErrorBit) 
-						|| (BitsCheck((char *)voice, NullVoice_ID31, 9) < MaxErrorBit)) 
-						&& SendHeader)
+					if (DprsSW)
 					{
-						SendToInet = FALSE;
-						SendHeader = FALSE;	/* header sending switch */
+						if (((BitsCheck((char *)voice, NullVoice0, 9) < MaxErrorBit) 
+							|| (BitsCheck((char *)voice, NullVoice_ID31, 9) < MaxErrorBit)) 
+							&& SendHeader)
+						{
+							SendToInet = FALSE;
+							SendHeader = FALSE;	/* header sending switch */
+						}
 					}
 					send_voice_queue();
 					Packet_Seq++;
@@ -192,6 +195,26 @@ void	send_voice_queue(void) 	/* read from rig (DV packet) */
 	dv_frame.B_header.PacketID[0] = (Packet_ID >> 8) & 0xff;
 	dv_frame.B_header.PacketID[1] = Packet_ID & 0xff;
 	memcpy ((char *)dv_frame.voice.voice, (char *)voice, 12);
+	if (DprsStrip)
+	{
+		if ((Packet_Seq % 2) == 1)
+		{
+			if (((dv_frame.voice.slowdata[0] ^ 0x70) & 0xf0) == 0x30)
+			{
+				dv_frame.voice.slowdata[0] = 0x66 ^ 0x70;
+				dv_frame.voice.slowdata[1] = 0x66 ^ 0x4f;
+				dv_frame.voice.slowdata[2] = 0x66 ^ 0x93;
+				DprsStripSW = TRUE;
+			}
+		}
+	}
+	if (DprsStripSW)
+	{
+		DprsStripSW = FALSE;
+		dv_frame.voice.slowdata[0] = 0x66 ^ 0x70;
+		dv_frame.voice.slowdata[1] = 0x66 ^ 0x4f;
+		dv_frame.voice.slowdata[2] = 0x66 ^ 0x93;
+	}
 	if (SendToInet) mq_send (rf_qid, (char *)&dv_frame, sizeof(dv_frame), 1);
 	if (repeater_mode)
 	{
